internal

package
v0.0.0-...-b605237 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 29, 2018 License: GPL-3.0 Imports: 8 Imported by: 0

README

Client Internal Package

This package should be used for test helpers and non-production code only! Mocks generated with gomock and omckgen will go in this package.

Documentation

Overview

Package internal is a generated GoMock package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAttesterServiceClient

type MockAttesterServiceClient struct {
	// contains filtered or unexported fields
}

MockAttesterServiceClient is a mock of AttesterServiceClient interface

func NewMockAttesterServiceClient

func NewMockAttesterServiceClient(ctrl *gomock.Controller) *MockAttesterServiceClient

NewMockAttesterServiceClient creates a new mock instance

func (*MockAttesterServiceClient) AttestHead

AttestHead mocks base method

func (*MockAttesterServiceClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

type MockAttesterServiceClientMockRecorder

type MockAttesterServiceClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockAttesterServiceClientMockRecorder is the mock recorder for MockAttesterServiceClient

func (*MockAttesterServiceClientMockRecorder) AttestHead

func (mr *MockAttesterServiceClientMockRecorder) AttestHead(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

AttestHead indicates an expected call of AttestHead

type MockBeaconServiceClient

type MockBeaconServiceClient struct {
	// contains filtered or unexported fields
}

MockBeaconServiceClient is a mock of BeaconServiceClient interface

func NewMockBeaconServiceClient

func NewMockBeaconServiceClient(ctrl *gomock.Controller) *MockBeaconServiceClient

NewMockBeaconServiceClient creates a new mock instance

func (*MockBeaconServiceClient) CanonicalHead

func (m *MockBeaconServiceClient) CanonicalHead(arg0 context.Context, arg1 *types.Empty, arg2 ...grpc.CallOption) (*v1.BeaconBlock, error)

CanonicalHead mocks base method

func (*MockBeaconServiceClient) CurrentAssignmentsAndGenesisTime

func (m *MockBeaconServiceClient) CurrentAssignmentsAndGenesisTime(arg0 context.Context, arg1 *v10.ValidatorAssignmentRequest, arg2 ...grpc.CallOption) (*v10.CurrentAssignmentsResponse, error)

CurrentAssignmentsAndGenesisTime mocks base method

func (*MockBeaconServiceClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockBeaconServiceClient) LatestAttestation

LatestAttestation mocks base method

func (*MockBeaconServiceClient) ValidatorAssignments

ValidatorAssignments mocks base method

type MockBeaconServiceClientMockRecorder

type MockBeaconServiceClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockBeaconServiceClientMockRecorder is the mock recorder for MockBeaconServiceClient

func (*MockBeaconServiceClientMockRecorder) CanonicalHead

func (mr *MockBeaconServiceClientMockRecorder) CanonicalHead(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

CanonicalHead indicates an expected call of CanonicalHead

func (*MockBeaconServiceClientMockRecorder) CurrentAssignmentsAndGenesisTime

func (mr *MockBeaconServiceClientMockRecorder) CurrentAssignmentsAndGenesisTime(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

CurrentAssignmentsAndGenesisTime indicates an expected call of CurrentAssignmentsAndGenesisTime

func (*MockBeaconServiceClientMockRecorder) LatestAttestation

func (mr *MockBeaconServiceClientMockRecorder) LatestAttestation(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

LatestAttestation indicates an expected call of LatestAttestation

func (*MockBeaconServiceClientMockRecorder) ValidatorAssignments

func (mr *MockBeaconServiceClientMockRecorder) ValidatorAssignments(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

ValidatorAssignments indicates an expected call of ValidatorAssignments

type MockBeaconService_LatestAttestationClient

type MockBeaconService_LatestAttestationClient struct {
	// contains filtered or unexported fields
}

MockBeaconService_LatestAttestationClient is a mock of BeaconService_LatestAttestationClient interface

func NewMockBeaconService_LatestAttestationClient

func NewMockBeaconService_LatestAttestationClient(ctrl *gomock.Controller) *MockBeaconService_LatestAttestationClient

NewMockBeaconService_LatestAttestationClient creates a new mock instance

func (*MockBeaconService_LatestAttestationClient) CloseSend

CloseSend mocks base method

func (*MockBeaconService_LatestAttestationClient) Context

Context mocks base method

func (*MockBeaconService_LatestAttestationClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockBeaconService_LatestAttestationClient) Header

Header mocks base method

func (*MockBeaconService_LatestAttestationClient) Recv

Recv mocks base method

func (*MockBeaconService_LatestAttestationClient) RecvMsg

func (m *MockBeaconService_LatestAttestationClient) RecvMsg(arg0 interface{}) error

RecvMsg mocks base method

func (*MockBeaconService_LatestAttestationClient) SendMsg

func (m *MockBeaconService_LatestAttestationClient) SendMsg(arg0 interface{}) error

SendMsg mocks base method

func (*MockBeaconService_LatestAttestationClient) Trailer

Trailer mocks base method

type MockBeaconService_LatestAttestationClientMockRecorder

type MockBeaconService_LatestAttestationClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockBeaconService_LatestAttestationClientMockRecorder is the mock recorder for MockBeaconService_LatestAttestationClient

func (*MockBeaconService_LatestAttestationClientMockRecorder) CloseSend

CloseSend indicates an expected call of CloseSend

func (*MockBeaconService_LatestAttestationClientMockRecorder) Context

Context indicates an expected call of Context

func (*MockBeaconService_LatestAttestationClientMockRecorder) Header

Header indicates an expected call of Header

func (*MockBeaconService_LatestAttestationClientMockRecorder) Recv

Recv indicates an expected call of Recv

func (*MockBeaconService_LatestAttestationClientMockRecorder) RecvMsg

func (mr *MockBeaconService_LatestAttestationClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call

RecvMsg indicates an expected call of RecvMsg

func (*MockBeaconService_LatestAttestationClientMockRecorder) SendMsg

func (mr *MockBeaconService_LatestAttestationClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call

SendMsg indicates an expected call of SendMsg

func (*MockBeaconService_LatestAttestationClientMockRecorder) Trailer

Trailer indicates an expected call of Trailer

type MockBeaconService_ValidatorAssignmentsClient

type MockBeaconService_ValidatorAssignmentsClient struct {
	// contains filtered or unexported fields
}

MockBeaconService_ValidatorAssignmentsClient is a mock of BeaconService_ValidatorAssignmentsClient interface

func NewMockBeaconService_ValidatorAssignmentsClient

func NewMockBeaconService_ValidatorAssignmentsClient(ctrl *gomock.Controller) *MockBeaconService_ValidatorAssignmentsClient

NewMockBeaconService_ValidatorAssignmentsClient creates a new mock instance

func (*MockBeaconService_ValidatorAssignmentsClient) CloseSend

CloseSend mocks base method

func (*MockBeaconService_ValidatorAssignmentsClient) Context

Context mocks base method

func (*MockBeaconService_ValidatorAssignmentsClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockBeaconService_ValidatorAssignmentsClient) Header

Header mocks base method

func (*MockBeaconService_ValidatorAssignmentsClient) Recv

Recv mocks base method

func (*MockBeaconService_ValidatorAssignmentsClient) RecvMsg

func (m *MockBeaconService_ValidatorAssignmentsClient) RecvMsg(arg0 interface{}) error

RecvMsg mocks base method

func (*MockBeaconService_ValidatorAssignmentsClient) SendMsg

func (m *MockBeaconService_ValidatorAssignmentsClient) SendMsg(arg0 interface{}) error

SendMsg mocks base method

func (*MockBeaconService_ValidatorAssignmentsClient) Trailer

Trailer mocks base method

type MockBeaconService_ValidatorAssignmentsClientMockRecorder

type MockBeaconService_ValidatorAssignmentsClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockBeaconService_ValidatorAssignmentsClientMockRecorder is the mock recorder for MockBeaconService_ValidatorAssignmentsClient

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) CloseSend

CloseSend indicates an expected call of CloseSend

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Context

Context indicates an expected call of Context

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Header

Header indicates an expected call of Header

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Recv

Recv indicates an expected call of Recv

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) RecvMsg

RecvMsg indicates an expected call of RecvMsg

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) SendMsg

SendMsg indicates an expected call of SendMsg

func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Trailer

Trailer indicates an expected call of Trailer

type MockProposerServiceClient

type MockProposerServiceClient struct {
	// contains filtered or unexported fields
}

MockProposerServiceClient is a mock of ProposerServiceClient interface

func NewMockProposerServiceClient

func NewMockProposerServiceClient(ctrl *gomock.Controller) *MockProposerServiceClient

NewMockProposerServiceClient creates a new mock instance

func (*MockProposerServiceClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockProposerServiceClient) ProposeBlock

ProposeBlock mocks base method

type MockProposerServiceClientMockRecorder

type MockProposerServiceClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockProposerServiceClientMockRecorder is the mock recorder for MockProposerServiceClient

func (*MockProposerServiceClientMockRecorder) ProposeBlock

func (mr *MockProposerServiceClientMockRecorder) ProposeBlock(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

ProposeBlock indicates an expected call of ProposeBlock

type MockValidatorServiceClient

type MockValidatorServiceClient struct {
	// contains filtered or unexported fields
}

MockValidatorServiceClient is a mock of ValidatorServiceClient interface

func NewMockValidatorServiceClient

func NewMockValidatorServiceClient(ctrl *gomock.Controller) *MockValidatorServiceClient

NewMockValidatorServiceClient creates a new mock instance

func (*MockValidatorServiceClient) EXPECT

EXPECT returns an object that allows the caller to indicate expected use

func (*MockValidatorServiceClient) ValidatorIndex

func (m *MockValidatorServiceClient) ValidatorIndex(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.IndexResponse, error)

ValidatorIndex mocks base method

func (*MockValidatorServiceClient) ValidatorShardID

func (m *MockValidatorServiceClient) ValidatorShardID(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.ShardIDResponse, error)

ValidatorShardID mocks base method

func (*MockValidatorServiceClient) ValidatorSlotAndResponsibility

func (m *MockValidatorServiceClient) ValidatorSlotAndResponsibility(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.SlotResponsibilityResponse, error)

ValidatorSlotAndResponsibility mocks base method

type MockValidatorServiceClientMockRecorder

type MockValidatorServiceClientMockRecorder struct {
	// contains filtered or unexported fields
}

MockValidatorServiceClientMockRecorder is the mock recorder for MockValidatorServiceClient

func (*MockValidatorServiceClientMockRecorder) ValidatorIndex

func (mr *MockValidatorServiceClientMockRecorder) ValidatorIndex(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

ValidatorIndex indicates an expected call of ValidatorIndex

func (*MockValidatorServiceClientMockRecorder) ValidatorShardID

func (mr *MockValidatorServiceClientMockRecorder) ValidatorShardID(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

ValidatorShardID indicates an expected call of ValidatorShardID

func (*MockValidatorServiceClientMockRecorder) ValidatorSlotAndResponsibility

func (mr *MockValidatorServiceClientMockRecorder) ValidatorSlotAndResponsibility(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call

ValidatorSlotAndResponsibility indicates an expected call of ValidatorSlotAndResponsibility

Jump to