Documentation
¶
Overview ¶
Package internal is a generated GoMock package.
Index ¶
- type MockAttesterServiceClient
- type MockAttesterServiceClientMockRecorder
- type MockBeaconServiceClient
- func (m *MockBeaconServiceClient) CanonicalHead(arg0 context.Context, arg1 *types.Empty, arg2 ...grpc.CallOption) (*v1.BeaconBlock, error)
- func (m *MockBeaconServiceClient) CurrentAssignmentsAndGenesisTime(arg0 context.Context, arg1 *v10.ValidatorAssignmentRequest, ...) (*v10.CurrentAssignmentsResponse, error)
- func (m *MockBeaconServiceClient) EXPECT() *MockBeaconServiceClientMockRecorder
- func (m *MockBeaconServiceClient) LatestAttestation(arg0 context.Context, arg1 *types.Empty, arg2 ...grpc.CallOption) (v10.BeaconService_LatestAttestationClient, error)
- func (m *MockBeaconServiceClient) ValidatorAssignments(arg0 context.Context, arg1 *v10.ValidatorAssignmentRequest, ...) (v10.BeaconService_ValidatorAssignmentsClient, error)
- type MockBeaconServiceClientMockRecorder
- func (mr *MockBeaconServiceClientMockRecorder) CanonicalHead(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
- func (mr *MockBeaconServiceClientMockRecorder) CurrentAssignmentsAndGenesisTime(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
- func (mr *MockBeaconServiceClientMockRecorder) LatestAttestation(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
- func (mr *MockBeaconServiceClientMockRecorder) ValidatorAssignments(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
- type MockBeaconService_LatestAttestationClient
- func (m *MockBeaconService_LatestAttestationClient) CloseSend() error
- func (m *MockBeaconService_LatestAttestationClient) Context() context.Context
- func (m *MockBeaconService_LatestAttestationClient) EXPECT() *MockBeaconService_LatestAttestationClientMockRecorder
- func (m *MockBeaconService_LatestAttestationClient) Header() (metadata.MD, error)
- func (m *MockBeaconService_LatestAttestationClient) Recv() (*v1.Attestation, error)
- func (m *MockBeaconService_LatestAttestationClient) RecvMsg(arg0 interface{}) error
- func (m *MockBeaconService_LatestAttestationClient) SendMsg(arg0 interface{}) error
- func (m *MockBeaconService_LatestAttestationClient) Trailer() metadata.MD
- type MockBeaconService_LatestAttestationClientMockRecorder
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) CloseSend() *gomock.Call
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Context() *gomock.Call
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Header() *gomock.Call
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Recv() *gomock.Call
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Trailer() *gomock.Call
- type MockBeaconService_ValidatorAssignmentsClient
- func (m *MockBeaconService_ValidatorAssignmentsClient) CloseSend() error
- func (m *MockBeaconService_ValidatorAssignmentsClient) Context() context.Context
- func (m *MockBeaconService_ValidatorAssignmentsClient) EXPECT() *MockBeaconService_ValidatorAssignmentsClientMockRecorder
- func (m *MockBeaconService_ValidatorAssignmentsClient) Header() (metadata.MD, error)
- func (m *MockBeaconService_ValidatorAssignmentsClient) Recv() (*v10.ValidatorAssignmentResponse, error)
- func (m *MockBeaconService_ValidatorAssignmentsClient) RecvMsg(arg0 interface{}) error
- func (m *MockBeaconService_ValidatorAssignmentsClient) SendMsg(arg0 interface{}) error
- func (m *MockBeaconService_ValidatorAssignmentsClient) Trailer() metadata.MD
- type MockBeaconService_ValidatorAssignmentsClientMockRecorder
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) CloseSend() *gomock.Call
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Context() *gomock.Call
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Header() *gomock.Call
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Recv() *gomock.Call
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Trailer() *gomock.Call
- type MockProposerServiceClient
- type MockProposerServiceClientMockRecorder
- type MockValidatorServiceClient
- func (m *MockValidatorServiceClient) EXPECT() *MockValidatorServiceClientMockRecorder
- func (m *MockValidatorServiceClient) ValidatorIndex(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.IndexResponse, error)
- func (m *MockValidatorServiceClient) ValidatorShardID(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.ShardIDResponse, error)
- func (m *MockValidatorServiceClient) ValidatorSlotAndResponsibility(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.SlotResponsibilityResponse, error)
- type MockValidatorServiceClientMockRecorder
- func (mr *MockValidatorServiceClientMockRecorder) ValidatorIndex(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
- func (mr *MockValidatorServiceClientMockRecorder) ValidatorShardID(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
- func (mr *MockValidatorServiceClientMockRecorder) ValidatorSlotAndResponsibility(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockAttesterServiceClient ¶
type MockAttesterServiceClient struct {
// contains filtered or unexported fields
}
MockAttesterServiceClient is a mock of AttesterServiceClient interface
func NewMockAttesterServiceClient ¶
func NewMockAttesterServiceClient(ctrl *gomock.Controller) *MockAttesterServiceClient
NewMockAttesterServiceClient creates a new mock instance
func (*MockAttesterServiceClient) AttestHead ¶
func (m *MockAttesterServiceClient) AttestHead(arg0 context.Context, arg1 *v1.AttestRequest, arg2 ...grpc.CallOption) (*v1.AttestResponse, error)
AttestHead mocks base method
func (*MockAttesterServiceClient) EXPECT ¶
func (m *MockAttesterServiceClient) EXPECT() *MockAttesterServiceClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
type MockAttesterServiceClientMockRecorder ¶
type MockAttesterServiceClientMockRecorder struct {
// contains filtered or unexported fields
}
MockAttesterServiceClientMockRecorder is the mock recorder for MockAttesterServiceClient
func (*MockAttesterServiceClientMockRecorder) AttestHead ¶
func (mr *MockAttesterServiceClientMockRecorder) AttestHead(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
AttestHead indicates an expected call of AttestHead
type MockBeaconServiceClient ¶
type MockBeaconServiceClient struct {
// contains filtered or unexported fields
}
MockBeaconServiceClient is a mock of BeaconServiceClient interface
func NewMockBeaconServiceClient ¶
func NewMockBeaconServiceClient(ctrl *gomock.Controller) *MockBeaconServiceClient
NewMockBeaconServiceClient creates a new mock instance
func (*MockBeaconServiceClient) CanonicalHead ¶
func (m *MockBeaconServiceClient) CanonicalHead(arg0 context.Context, arg1 *types.Empty, arg2 ...grpc.CallOption) (*v1.BeaconBlock, error)
CanonicalHead mocks base method
func (*MockBeaconServiceClient) CurrentAssignmentsAndGenesisTime ¶
func (m *MockBeaconServiceClient) CurrentAssignmentsAndGenesisTime(arg0 context.Context, arg1 *v10.ValidatorAssignmentRequest, arg2 ...grpc.CallOption) (*v10.CurrentAssignmentsResponse, error)
CurrentAssignmentsAndGenesisTime mocks base method
func (*MockBeaconServiceClient) EXPECT ¶
func (m *MockBeaconServiceClient) EXPECT() *MockBeaconServiceClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBeaconServiceClient) LatestAttestation ¶
func (m *MockBeaconServiceClient) LatestAttestation(arg0 context.Context, arg1 *types.Empty, arg2 ...grpc.CallOption) (v10.BeaconService_LatestAttestationClient, error)
LatestAttestation mocks base method
func (*MockBeaconServiceClient) ValidatorAssignments ¶
func (m *MockBeaconServiceClient) ValidatorAssignments(arg0 context.Context, arg1 *v10.ValidatorAssignmentRequest, arg2 ...grpc.CallOption) (v10.BeaconService_ValidatorAssignmentsClient, error)
ValidatorAssignments mocks base method
type MockBeaconServiceClientMockRecorder ¶
type MockBeaconServiceClientMockRecorder struct {
// contains filtered or unexported fields
}
MockBeaconServiceClientMockRecorder is the mock recorder for MockBeaconServiceClient
func (*MockBeaconServiceClientMockRecorder) CanonicalHead ¶
func (mr *MockBeaconServiceClientMockRecorder) CanonicalHead(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
CanonicalHead indicates an expected call of CanonicalHead
func (*MockBeaconServiceClientMockRecorder) CurrentAssignmentsAndGenesisTime ¶
func (mr *MockBeaconServiceClientMockRecorder) CurrentAssignmentsAndGenesisTime(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
CurrentAssignmentsAndGenesisTime indicates an expected call of CurrentAssignmentsAndGenesisTime
func (*MockBeaconServiceClientMockRecorder) LatestAttestation ¶
func (mr *MockBeaconServiceClientMockRecorder) LatestAttestation(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
LatestAttestation indicates an expected call of LatestAttestation
func (*MockBeaconServiceClientMockRecorder) ValidatorAssignments ¶
func (mr *MockBeaconServiceClientMockRecorder) ValidatorAssignments(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
ValidatorAssignments indicates an expected call of ValidatorAssignments
type MockBeaconService_LatestAttestationClient ¶
type MockBeaconService_LatestAttestationClient struct {
// contains filtered or unexported fields
}
MockBeaconService_LatestAttestationClient is a mock of BeaconService_LatestAttestationClient interface
func NewMockBeaconService_LatestAttestationClient ¶
func NewMockBeaconService_LatestAttestationClient(ctrl *gomock.Controller) *MockBeaconService_LatestAttestationClient
NewMockBeaconService_LatestAttestationClient creates a new mock instance
func (*MockBeaconService_LatestAttestationClient) CloseSend ¶
func (m *MockBeaconService_LatestAttestationClient) CloseSend() error
CloseSend mocks base method
func (*MockBeaconService_LatestAttestationClient) Context ¶
func (m *MockBeaconService_LatestAttestationClient) Context() context.Context
Context mocks base method
func (*MockBeaconService_LatestAttestationClient) EXPECT ¶
func (m *MockBeaconService_LatestAttestationClient) EXPECT() *MockBeaconService_LatestAttestationClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBeaconService_LatestAttestationClient) Header ¶
func (m *MockBeaconService_LatestAttestationClient) Header() (metadata.MD, error)
Header mocks base method
func (*MockBeaconService_LatestAttestationClient) Recv ¶
func (m *MockBeaconService_LatestAttestationClient) Recv() (*v1.Attestation, error)
Recv mocks base method
func (*MockBeaconService_LatestAttestationClient) RecvMsg ¶
func (m *MockBeaconService_LatestAttestationClient) RecvMsg(arg0 interface{}) error
RecvMsg mocks base method
func (*MockBeaconService_LatestAttestationClient) SendMsg ¶
func (m *MockBeaconService_LatestAttestationClient) SendMsg(arg0 interface{}) error
SendMsg mocks base method
func (*MockBeaconService_LatestAttestationClient) Trailer ¶
func (m *MockBeaconService_LatestAttestationClient) Trailer() metadata.MD
Trailer mocks base method
type MockBeaconService_LatestAttestationClientMockRecorder ¶
type MockBeaconService_LatestAttestationClientMockRecorder struct {
// contains filtered or unexported fields
}
MockBeaconService_LatestAttestationClientMockRecorder is the mock recorder for MockBeaconService_LatestAttestationClient
func (*MockBeaconService_LatestAttestationClientMockRecorder) CloseSend ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) CloseSend() *gomock.Call
CloseSend indicates an expected call of CloseSend
func (*MockBeaconService_LatestAttestationClientMockRecorder) Context ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Context() *gomock.Call
Context indicates an expected call of Context
func (*MockBeaconService_LatestAttestationClientMockRecorder) Header ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Header() *gomock.Call
Header indicates an expected call of Header
func (*MockBeaconService_LatestAttestationClientMockRecorder) Recv ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Recv() *gomock.Call
Recv indicates an expected call of Recv
func (*MockBeaconService_LatestAttestationClientMockRecorder) RecvMsg ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
RecvMsg indicates an expected call of RecvMsg
func (*MockBeaconService_LatestAttestationClientMockRecorder) SendMsg ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
SendMsg indicates an expected call of SendMsg
func (*MockBeaconService_LatestAttestationClientMockRecorder) Trailer ¶
func (mr *MockBeaconService_LatestAttestationClientMockRecorder) Trailer() *gomock.Call
Trailer indicates an expected call of Trailer
type MockBeaconService_ValidatorAssignmentsClient ¶
type MockBeaconService_ValidatorAssignmentsClient struct {
// contains filtered or unexported fields
}
MockBeaconService_ValidatorAssignmentsClient is a mock of BeaconService_ValidatorAssignmentsClient interface
func NewMockBeaconService_ValidatorAssignmentsClient ¶
func NewMockBeaconService_ValidatorAssignmentsClient(ctrl *gomock.Controller) *MockBeaconService_ValidatorAssignmentsClient
NewMockBeaconService_ValidatorAssignmentsClient creates a new mock instance
func (*MockBeaconService_ValidatorAssignmentsClient) CloseSend ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) CloseSend() error
CloseSend mocks base method
func (*MockBeaconService_ValidatorAssignmentsClient) Context ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) Context() context.Context
Context mocks base method
func (*MockBeaconService_ValidatorAssignmentsClient) EXPECT ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) EXPECT() *MockBeaconService_ValidatorAssignmentsClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBeaconService_ValidatorAssignmentsClient) Header ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) Header() (metadata.MD, error)
Header mocks base method
func (*MockBeaconService_ValidatorAssignmentsClient) Recv ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) Recv() (*v10.ValidatorAssignmentResponse, error)
Recv mocks base method
func (*MockBeaconService_ValidatorAssignmentsClient) RecvMsg ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) RecvMsg(arg0 interface{}) error
RecvMsg mocks base method
func (*MockBeaconService_ValidatorAssignmentsClient) SendMsg ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) SendMsg(arg0 interface{}) error
SendMsg mocks base method
func (*MockBeaconService_ValidatorAssignmentsClient) Trailer ¶
func (m *MockBeaconService_ValidatorAssignmentsClient) Trailer() metadata.MD
Trailer mocks base method
type MockBeaconService_ValidatorAssignmentsClientMockRecorder ¶
type MockBeaconService_ValidatorAssignmentsClientMockRecorder struct {
// contains filtered or unexported fields
}
MockBeaconService_ValidatorAssignmentsClientMockRecorder is the mock recorder for MockBeaconService_ValidatorAssignmentsClient
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) CloseSend ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) CloseSend() *gomock.Call
CloseSend indicates an expected call of CloseSend
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Context ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Context() *gomock.Call
Context indicates an expected call of Context
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Header ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Header() *gomock.Call
Header indicates an expected call of Header
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Recv ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Recv() *gomock.Call
Recv indicates an expected call of Recv
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) RecvMsg ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
RecvMsg indicates an expected call of RecvMsg
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) SendMsg ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
SendMsg indicates an expected call of SendMsg
func (*MockBeaconService_ValidatorAssignmentsClientMockRecorder) Trailer ¶
func (mr *MockBeaconService_ValidatorAssignmentsClientMockRecorder) Trailer() *gomock.Call
Trailer indicates an expected call of Trailer
type MockProposerServiceClient ¶
type MockProposerServiceClient struct {
// contains filtered or unexported fields
}
MockProposerServiceClient is a mock of ProposerServiceClient interface
func NewMockProposerServiceClient ¶
func NewMockProposerServiceClient(ctrl *gomock.Controller) *MockProposerServiceClient
NewMockProposerServiceClient creates a new mock instance
func (*MockProposerServiceClient) EXPECT ¶
func (m *MockProposerServiceClient) EXPECT() *MockProposerServiceClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockProposerServiceClient) ProposeBlock ¶
func (m *MockProposerServiceClient) ProposeBlock(arg0 context.Context, arg1 *v1.ProposeRequest, arg2 ...grpc.CallOption) (*v1.ProposeResponse, error)
ProposeBlock mocks base method
type MockProposerServiceClientMockRecorder ¶
type MockProposerServiceClientMockRecorder struct {
// contains filtered or unexported fields
}
MockProposerServiceClientMockRecorder is the mock recorder for MockProposerServiceClient
func (*MockProposerServiceClientMockRecorder) ProposeBlock ¶
func (mr *MockProposerServiceClientMockRecorder) ProposeBlock(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
ProposeBlock indicates an expected call of ProposeBlock
type MockValidatorServiceClient ¶
type MockValidatorServiceClient struct {
// contains filtered or unexported fields
}
MockValidatorServiceClient is a mock of ValidatorServiceClient interface
func NewMockValidatorServiceClient ¶
func NewMockValidatorServiceClient(ctrl *gomock.Controller) *MockValidatorServiceClient
NewMockValidatorServiceClient creates a new mock instance
func (*MockValidatorServiceClient) EXPECT ¶
func (m *MockValidatorServiceClient) EXPECT() *MockValidatorServiceClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockValidatorServiceClient) ValidatorIndex ¶
func (m *MockValidatorServiceClient) ValidatorIndex(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.IndexResponse, error)
ValidatorIndex mocks base method
func (*MockValidatorServiceClient) ValidatorShardID ¶
func (m *MockValidatorServiceClient) ValidatorShardID(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.ShardIDResponse, error)
ValidatorShardID mocks base method
func (*MockValidatorServiceClient) ValidatorSlotAndResponsibility ¶
func (m *MockValidatorServiceClient) ValidatorSlotAndResponsibility(arg0 context.Context, arg1 *v1.PublicKey, arg2 ...grpc.CallOption) (*v1.SlotResponsibilityResponse, error)
ValidatorSlotAndResponsibility mocks base method
type MockValidatorServiceClientMockRecorder ¶
type MockValidatorServiceClientMockRecorder struct {
// contains filtered or unexported fields
}
MockValidatorServiceClientMockRecorder is the mock recorder for MockValidatorServiceClient
func (*MockValidatorServiceClientMockRecorder) ValidatorIndex ¶
func (mr *MockValidatorServiceClientMockRecorder) ValidatorIndex(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
ValidatorIndex indicates an expected call of ValidatorIndex
func (*MockValidatorServiceClientMockRecorder) ValidatorShardID ¶
func (mr *MockValidatorServiceClientMockRecorder) ValidatorShardID(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
ValidatorShardID indicates an expected call of ValidatorShardID
func (*MockValidatorServiceClientMockRecorder) ValidatorSlotAndResponsibility ¶
func (mr *MockValidatorServiceClientMockRecorder) ValidatorSlotAndResponsibility(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
ValidatorSlotAndResponsibility indicates an expected call of ValidatorSlotAndResponsibility